# pptitles

Extract the slide number and title from all slides in a PowerPoint presentation.

## Install from PyPi

`python3 -m pip install pptitles`

## Usage:

`pptitles "/path/to/presentation.pptx"`
